@@ -49,6 +49,28 @@ def filter_exclude(matches, patterns):
     return output
 
 
+def find(args):
+    if args.pattern == "robotframework":
+        matches = finder.builtins()
+        include = "*"
+    elif args.pattern == "rpaframework":
+        matches = finder.rpaframework()
+        include = "*"
+    else:
+        matches = finder.find_all(curdir=(not args.no_curdir))
+        include = args.pattern
+
+    return matches, include
+
+
+def try_load(match):
+    try:
+        logging.debug("Loading %s", match)
+        return loader.load(match)
+    except ImportError:
+        debug_traceback()
+
+
 def create_parser():
     parser = argparse.ArgumentParser(
         description=__doc__, formatter_class=argparse.RawTextHelpFormatter
@@ -96,27 +118,6 @@ def create_parser():
     return parser
 
 
-def find(args):
-    if args.pattern == "robotframework":
-        matches = finder.builtins()
-        include = "*"
-    elif args.pattern == "rpaframework":
-        matches = finder.rpaframework()
-        include = "*"
-    else:
-        matches = finder.find_all(curdir=(not args.no_curdir))
-        include = args.pattern
-
-    return matches, include
-
-
-def try_load(match):
-    try:
-        return loader.load(match)
-    except ImportError:
-        debug_traceback()
-
-
 def run(raw_args=None):
     parser = create_parser()
     args = parser.parse_args(raw_args)
@@ -131,6 +132,7 @@ def run(raw_args=None):
     with timed("All"):
         with timed("Find"):
             matches, include = find(args)
+            matches.sort()
 
         with timed("Filter"):
             matches = filter_include(matches, [include])
