@@ -5,13 +5,17 @@ import re
 from collections import defaultdict
 from pathlib import Path
 from robot.libdocpkg import htmlwriter
+from robot.libdocpkg.model import LibraryDoc
 from docgen import rest
+from robot.version import VERSION
+
+RF_VERSION = VERSION
 
 # Populated dynamically
 CONVERTERS = {}
 
 
-def convert(libdoc, fmt, dirname):
+def convert(libdoc: LibraryDoc, fmt, dirname):
     """Convert libdoc model into output file."""
     converter = CONVERTERS.get(fmt)
     if not converter:
@@ -20,7 +24,7 @@ def convert(libdoc, fmt, dirname):
     filename = Path(libdoc.name.replace(".", "_"))
     filename = filename.with_suffix(converter.EXTENSION)
 
-    path = Path(dirname) / filename
+    path = str(Path(dirname) / filename)
     converter().convert(libdoc, path)
     logging.info("Created file: %s", path)
 
@@ -47,7 +51,7 @@ class BaseConverter(metaclass=ConverterMeta):
     EXTENSION = None
 
     @abc.abstractmethod
-    def convert(self, libdoc, output):
+    def convert(self, libdoc: LibraryDoc, output):
         raise NotImplementedError
 
 
@@ -59,44 +63,51 @@ class JsonConverter(BaseConverter):
         def html(self, doc, *args, **kwargs):
             return doc
 
-    def convert(self, libdoc, output):
-        data = htmlwriter.JsonConverter(self._NullFormatter()).convert(libdoc)
-        with open(output, "w") as fd:
-            json.dump(data, fd, indent=4)
+    def convert(self, libdoc: LibraryDoc, output):
+        if int(RF_VERSION[0]) <= 3:
+            data = htmlwriter.JsonConverter(self._NullFormatter()).convert(libdoc)
+            with open(output, "w") as fd:
+                json.dump(data, fd, indent=4)
+        else:
+            libdoc.save(output, "JSON")
 
 
 class JsonHtmlConverter(BaseConverter):
     NAME = "json-html"
     EXTENSION = ".json"
 
-    def convert(self, libdoc, output):
-        formatter = htmlwriter.DocFormatter(
-            libdoc.keywords, libdoc.doc, libdoc.doc_format
-        )
-        data = htmlwriter.JsonConverter(formatter).convert(libdoc)
+    def convert(self, libdoc: LibraryDoc, output):
+        if int(RF_VERSION[0]) <= 3:
+            formatter = htmlwriter.DocFormatter(
+                libdoc.keywords, libdoc.doc, libdoc.doc_format
+            )
+            data = htmlwriter.JsonConverter(formatter).convert(libdoc)
 
-        # Format keyword shortdoc with correct formatter, strip extra HTML tags
-        for keyword in data["keywords"]:
-            shortdoc = formatter.html(keyword["shortdoc"])
-            shortdoc = re.search(r"<p>(.*)<\/p>", shortdoc)
+            # Format keyword shortdoc with correct formatter, strip extra HTML tags
+            for keyword in data["keywords"]:
+                shortdoc = formatter.html(keyword["shortdoc"])
+                shortdoc = re.search(r"<p>(.*)<\/p>", shortdoc)
 
-            if shortdoc is None:
-                logging.warning(
-                    "Missing shortdoc: %s.%s", data["name"], keyword["name"]
-                )
-                continue
+                if shortdoc is None:
+                    logging.warning(
+                        "Missing shortdoc: %s.%s", data["name"], keyword["name"]
+                    )
+                    continue
 
-            keyword["shortdoc"] = shortdoc.group(1)
+                keyword["shortdoc"] = shortdoc.group(1)
 
-        with open(output, "w") as fd:
-            json.dump(data, fd, indent=4)
+            with open(output, "w") as fd:
+                json.dump(data, fd, indent=4)
+        else:
+            libdoc.convert_docs_to_html()
+            libdoc.save(output, "JSON")
 
 
 class XmlConverter(BaseConverter):
     NAME = "xml"
     EXTENSION = ".xml"
 
-    def convert(self, libdoc, output):
+    def convert(self, libdoc: LibraryDoc, output):
         libdoc.save(output, "XML")
 
 
@@ -104,7 +115,9 @@ class HtmlConverter(BaseConverter):
     NAME = "html"
     EXTENSION = ".html"
 
-    def convert(self, libdoc, output):
+    def convert(self, libdoc: LibraryDoc, output):
+        if int(RF_VERSION[0]) >= 4:
+            libdoc.convert_docs_to_html()
         libdoc.save(output, "HTML")
 
 
@@ -112,8 +125,12 @@ class XmlHtmlConverter(BaseConverter):
     NAME = "xml-html"
     EXTENSION = ".html"
 
-    def convert(self, libdoc, output):
-        libdoc.save(output, "XML:HTML")
+    def convert(self, libdoc: LibraryDoc, output):
+        if int(RF_VERSION[0]) <= 3:
+            libdoc.save(output, "XML:HTML")
+        else:
+            libdoc.convert_docs_to_html()
+            libdoc.save(output, "XML")
 
 
 class RestConverter(BaseConverter):
@@ -125,11 +142,11 @@ class RestConverter(BaseConverter):
     def __init__(self):
         self.ignore_block = False
 
-    def convert(self, libdoc, output):
+    def convert(self, libdoc: LibraryDoc, output):
         writer = rest.RestWriter()
         with writer.heading(libdoc.name):
             self.overview(writer, libdoc)
-            # self.inits(writer, libdoc)
+            self.inits(writer, libdoc)
             self.keywords(writer, libdoc)
         writer.save(output)
 
@@ -147,20 +164,20 @@ class RestConverter(BaseConverter):
         return "\n".join(output)
 
     @staticmethod
-    def escape_string(text):
+    def escape_string(text: str):
         return text.replace("*", "\\*")
 
-    def overview(self, writer, libdoc):
+    def overview(self, writer, libdoc: LibraryDoc):
         with writer.heading("Description"):
             writer.fieldlist(("Library scope", libdoc.scope))
             writer.raw(self.filter_docstring(libdoc.doc))
 
-    def inits(self, writer, libdoc):
+    def inits(self, writer, libdoc: LibraryDoc):
         with writer.heading("Init"):
             for init in libdoc.inits:
                 writer.raw(init.doc)
 
-    def keywords(self, writer, libdoc):
+    def keywords(self, writer, libdoc: LibraryDoc):
         groups = defaultdict(list)
         for keyword in libdoc.keywords:
             name = Path(keyword.source).stem
@@ -185,8 +202,14 @@ class RestConverter(BaseConverter):
         with writer.field(keyword.name):
             fields = []
             if keyword.args:
-                args = (self.escape_string(arg) for arg in keyword.args)
-                fields.append(("Arguments", ", ".join(args)))
+                if int(RF_VERSION[0]) <= 3:
+                    args = (self.escape_string(arg) for arg in keyword.args)
+                    fields.append(("Arguments", ", ".join(args)))
+                else:
+
+                    args = (str(arg) for arg in keyword.args)
+                    fields.append(("Arguments", ", ".join(args)))
+
             if keyword.tags:
                 fields.append(("Tags", ", ".join(keyword.tags)))
             writer.fieldlist(*fields)
@@ -197,10 +220,16 @@ class RestHtmlConverter(RestConverter):
     NAME = "rest-html"
     EXTENSION = ".rst"
 
-    def convert(self, libdoc, output):
-        formatter = htmlwriter.DocFormatter(
-            libdoc.keywords, libdoc.doc, libdoc.doc_format
-        )
+    def convert(self, libdoc: LibraryDoc, output):
+        if int(RF_VERSION[0]) <= 3:
+            DocFormatter = htmlwriter.DocFormatter
+            formatter = DocFormatter(libdoc.keywords, libdoc.doc, libdoc.doc_format)
+        else:
+            from robot.libdocpkg.htmlutils import DocFormatter
+
+            formatter = DocFormatter(
+                libdoc.keywords, libdoc.data_types, libdoc.doc, libdoc.doc_format
+            )
 
         doc = self._raw_html(formatter.html(libdoc.doc))
         try:
@@ -209,11 +238,13 @@ class RestHtmlConverter(RestConverter):
         except AttributeError:
             # Robot Framework >= 3.2
             libdoc._doc = doc
-
         for init in libdoc.inits:
             init.doc = self._raw_html(formatter.html(init.doc))
         for kw in libdoc.keywords:
             kw.doc = self._raw_html(formatter.html(kw.doc))
+        if int(RF_VERSION[0]) >= 4:
+            for type in libdoc.data_types:
+                type.doc = self._raw_html(formatter.html(type.doc))
 
         super().convert(libdoc, output)
 
